<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kab">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN tefarawen</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN tefassaden</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock tefarawen</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock tefassaden</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Keypad ntnar tefarawen</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Keypad ntnar tefassaden</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Touchpad tefarawen</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Touchpad tefassaden</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Tefassaden/tefarawen Touchpad</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Tefassaden/tefarawen Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Mod tefarawen airplain tefarawen</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Mod tefarawen airplain tefassaden</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Tefarawen erghen tafellal</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Tefassaden erghen tafellal</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Tefarawen erghen tafellal asghar</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Tefarawen efek tefassaden fenana</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Tefassaden efek tefassaden fenana</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Chaf tefassaden tefarawen efek tefassaden fenana</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>